@@ -4,7 +4,7 @@ use v5.16; # or newer
 use strict;
 use warnings;
 
-our $VERSION = "1.04";
+our $VERSION = "1.05";
 
 use JSON::PP;
 use Text::Diff;
@@ -748,7 +748,7 @@ __END__
 
 =head1 NAME
 
-OcToolkit - Open Cloud Toolkit
+Open Cloud Toolkit - OcToolkit -  A Helm-like Perl module for managing Openshift and Kubernetes projects
 
 =head1 SYNOPSIS
 
@@ -798,14 +798,6 @@ Copyright (C) John Summers.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 NAME
-
-This summary was generated with help from chatgpt-4
-
-=head1 NAME
-
-OcToolkit - A Helm-like Perl module for managing Openshift and Kubernetes deployments
-
 =head1 OVERVIEW
 
 OcToolkit (short for Open Cloud Toolkit) is a Perl module designed as a Helm-like toolkit for managing Openshift (and Kubernetes) projects, with added support for multi-cluster workflows.
@@ -846,7 +838,7 @@ Deletes resources based on generated YAML templates using C<oc delete>.
 
 =head2 Templating Engine
 
-Accepts Template Toolkit files (C<.tt>) and data configuration to generate deployment YAMLs.
+Accepts Template Toolkit files (C<.tt>) and data configuration to generate deployment and other YAMLs.
 
 Organizes templates by directory (often prefixed numerically for order) and processes directories in sequence.
 
@@ -915,11 +907,11 @@ Here's the typical flow from the module's documentation:
         # ... plus any advanced callbacks or settings
     );
 
-    $ocObj->install('test-instance');
-    $ocObj->validate('test-instance');
-    $ocObj->upgrade('test-instance');
+    $ocObj->install('testInstance');
+    $ocObj->validate('testInstance');
+    $ocObj->upgrade('testInstance');
     $ocObj->backup('production');
-    $ocObj->delete('dev-instance');
+    $ocObj->delete('devInstance');
 
 =head1 SUMMARY
 
@@ -947,15 +939,18 @@ Encodes and injects secrets at runtime securely.
 
 =back
 
-=head1 FINAL THOUGHT
+=head1 NOTE
 
-OcToolkit appears to be a robust and flexible Perl-based alternative to Helm, offering templated deployment workflows with validation, backups, and multi-cluster capabilities.
+If you are intrested in 'ocToolkit' command line tool only as an end user, see link to Gitlab in Description
 
-If you're familiar with Helm but prefer a Perl-centric, highly customizable tool, this could be a great fit!
+=head1 CONCLUSION
+
+OcToolkit is a robust and flexible Perl-based alternative to Helm, offering templated deployment workflows with validation, backups, and multi-cluster capabilities.
+
+If you're familiar with Helm but prefer a Perl-centric, highly customizable tool, this could be a great fit.
 
 =cut
 
-
 =head1 AUTHOR
 
 John Summers E<lt>devp2000a@gmail.comE<gt>
